pub enum ReinterpretCodecError {
InvalidReinterpret {
decode_dtype: AnyArrayDType,
encode_dtype: AnyArrayDType,
},
MismatchedEncodeDType {
configured: AnyArrayDType,
provided: AnyArrayDType,
},
MismatchedDecodeDType {
configured: AnyArrayDType,
provided: AnyArrayDType,
},
InvalidEncodedShape {
shape: Vec<usize>,
dtype: AnyArrayDType,
},
MismatchedDecodeIntoArray {
source: AnyArrayAssignError,
},
}Expand description
Errors that may occur when applying the ReinterpretCodec.
Variants
InvalidReinterpret
ReinterpretCodec cannot cannot bitcast the decode_dtype as
encode_dtype
Fields
decode_dtype: AnyArrayDTypeDtype of the configured decode_dtype
encode_dtype: AnyArrayDTypeDtype of the configured encode_dtype
MismatchedEncodeDType
ReinterpretCodec cannot encode the provided dtype which differs
from the configured dtype
Fields
configured: AnyArrayDTypeDtype of the configured decode_dtype
provided: AnyArrayDTypeDtype of the provided array from which the data is to be encoded
MismatchedDecodeDType
ReinterpretCodec cannot decode the provided dtype which differs
from the configured dtype
Fields
configured: AnyArrayDTypeDtype of the configured encode_dtype
provided: AnyArrayDTypeDtype of the provided array from which the data is to be decoded
InvalidEncodedShape
ReinterpretCodec cannot decode a byte array with shape into an array of dtypes
Fields
dtype: AnyArrayDTypeDtype of the array into which the encoded data is to be decoded
MismatchedDecodeIntoArray
ReinterpretCodec cannot decode into the provided array
Fields
source: AnyArrayAssignErrorThe source of the error